#startscreen

import random

import pygame, pygame.draw, pygame.transform
from pygame.locals import *
import game, scoreboard, words


buttons = {'gotit': Rect(1, 1, 123, 60),
           'passit': Rect(20, 76, 83, 30),
           'hot': Rect(5, 153, 111, 30),
           'cold': Rect(5, 189, 111, 30),
           'palette': Rect(10, 250, 101, 54),
           'erase': Rect(19, 333, 88, 22)}

canvaspos = Rect(130, 0, 510, 360)
clockpos = Rect(510, 250, 127, 118)

class GameMode:
    def __init__(self):
        self.color = 0, 0, 0
        self.start = pygame.time.get_ticks()
        self.mousedown = 0
        self.messages = []
        self.lastpos = None
        self.word = words.getword(game.easyhard)
        self.wordimage = None
        self.ticks = game.sound['clocktick'].play(-1)
        self.canvas = pygame.Surface(canvaspos.size)
        self.canvas.fill(game.canvascolor)

        game.screen.blit(game.graphic['paintbgd'], (0,0))
        scoreboard.draw(1)
        self.drawcanvas()
        
        self.drawcolor()
        game.dirty = [game.screen.get_rect()]
        
    def drawclock(self):
        game.screen.blit(game.graphic['clockface'], clockpos)
        angle = (pygame.time.get_ticks()-self.start)/game.painttime * 360
        arm = game.graphic['clockarm']
        arm = pygame.transform.rotate(arm, angle)
        r = arm.get_rect()
        r.center = clockpos.move(0, 5).center
        game.screen.blit(arm, r)
        game.dirty.append(clockpos)

    def drawcolor(self):
        r = buttons['palette'].inflate(8, 8)
        pts = r.topleft, r.topright, r.bottomright, r.bottomleft
        r = pygame.draw.lines(game.screen, self.color, 1, pts, 4)
        game.dirty.append(r)

    def drawcanvas(self):
        game.screen.blit(self.canvas, canvaspos)

        for m in self.messages[:]:
            if not m[0]:
                self.messages.remove(m)
                continue
            m[0] -= 1
            game.screen.blit(m[2], m[1])

        self.drawclock()

        if not self.wordimage:
            text = 'your word is: ' + self.word.upper()
            self.wordimage = game.thinfont.render(text, 0, (250, 240, 200))
        r = self.wordimage.get_rect()
        r.topright = 635, 5
        game.screen.blit(self.wordimage, r)

        game.dirty.append(canvaspos)

    def warpmouse(self, pos):
        return pos[0]-canvaspos.left, pos[1]

    def startstroke(self, pos):
        self.lastpos = pos
        pygame.draw.circle(self.canvas, self.color, pos, 2, 0)
        self.drawcanvas()
        
    def createstroke(self, pos):
        if pos != self.lastpos:
            pygame.draw.line(self.canvas, self.color, self.lastpos, pos, 5)
            self.lastpos = pos
            #draw end circle?
            self.drawcanvas()
        
    def endstroke(self):
        #draw end circle?
        self.lastpos = None
        #self.drawcanvas()
        
    def tick(self, event):
        self.event = event
        if event.type == MOUSEBUTTONDOWN:
            self.mousedown = 1
            if event.pos[0] < 125: #in controlbar
                for f, r in buttons.items():
                    if r.collidepoint(event.pos):
                        getattr(self, f)()
            elif canvaspos.collidepoint(event.pos):
                self.startstroke(self.warpmouse(event.pos))
        elif event.type == MOUSEBUTTONUP:
            self.mousedown = 0
            self.endstroke()
        elif event.type == NOEVENT:
            if pygame.time.get_ticks()-self.start > game.painttime:
                self.timeout()
                return
            if self.messages:
                self.drawcanvas()
            else:
                self.drawclock()
        elif event.type == MOUSEMOTION:
            if self.mousedown and buttons['palette'].collidepoint(event.pos):
                self.event = event
                self.palette()
            elif self.lastpos:
                self.createstroke(self.warpmouse(event.pos))

    def passit(self):
        self.start -= game.passtime
        self.word = words.getword(game.easyhard)
        self.wordimage = None
        self.erase()
        img = game.graphic['pass']
        r = img.get_rect()
        pos = (random.randint(0, canvaspos.width-r.width)+canvaspos.left,
               random.randint(0, canvaspos.height-r.height))
        self.messages.append([40, pos, img])


    def gotit(self):
        self.ticks.stop()
        game.sound['fanfare%d'%random.randint(1,8)].play()
        import endturn
        game.gamemode = endturn.GameMode(1, self.word)

    def timeout(self):
        self.ticks.stop()
        game.sound['firealarm'].play()
        import endturn
        game.gamemode = endturn.GameMode(0, self.word)

    def palette(self):
        self.color = game.graphic['paintbgd'].get_at(self.event.pos)
        self.drawcolor()

    def erase(self):
        self.canvas.fill(game.canvascolor)
        self.drawcanvas()

    def hot(self):
        img = game.graphic['hot']
        r = img.get_rect()
        pos = (random.randint(0, canvaspos.width-r.width)+canvaspos.left,
               random.randint(0, canvaspos.height-r.height))
        self.messages.append([26, pos, img])

    def cold(self):
        img = game.graphic['cold']
        r = img.get_rect()
        pos = (random.randint(0, canvaspos.width-r.width)+canvaspos.left,
               random.randint(0, canvaspos.height-r.height))
        self.messages.append([26, pos, img])
